==> certmanager-model-v1alpha3-6.8.0-sources.jar: io/fabric8/certmanager/api/model/v1alpha3/VenafiTPPFluent.java <==
package io.fabric8.certmanager.api.model.v1alpha3;

import java.lang.SuppressWarnings;
import io.fabric8.certmanager.api.model.meta.v1.LocalObjectReference;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.Object;
import java.lang.String;
import io.fabric8.certmanager.api.model.meta.v1.LocalObjectReferenceBuilder;
import io.fabric8.certmanager.api.model.meta.v1.LocalObjectReferenceFluent;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class VenafiTPPFluent<A extends VenafiTPPFluent<A>> extends BaseFluent<A>{
  public VenafiTPPFluent() {
  }
  public VenafiTPPFluent(VenafiTPP instance) {
    instance = (instance != null ? instance : new VenafiTPP());

    if (instance != null) {
      this.withCaBundle(instance.getCaBundle());
      this.withCredentialsRef(instance.getCredentialsRef());
      this.withUrl(instance.getUrl());
      this.withCaBundle(instance.getCaBundle());
      this.withCredentialsRef(instance.getCredentialsRef());
      this.withUrl(instance.getUrl());
    }
  }
  private String caBundle;
  private LocalObjectReferenceBuilder credentialsRef;
  private String url;
  public String getCaBundle() {
    return this.caBundle;
  }
  public A withCaBundle(String caBundle) {
    this.caBundle=caBundle; return (A) this;
  }
  public boolean hasCaBundle() {
    return this.caBundle != null;
  }
  public LocalObjectReference buildCredentialsRef() {
    return this.credentialsRef!=null ?this.credentialsRef.build():null;
  }
  public A withCredentialsRef(LocalObjectReference credentialsRef) {
    _visitables.get("credentialsRef").remove(this.credentialsRef);
    if (credentialsRef!=null){ this.credentialsRef= new LocalObjectReferenceBuilder(credentialsRef); _visitables.get("credentialsRef").add(this.credentialsRef);} else { this.credentialsRef = null; _visitables.get("credentialsRef").remove(this.credentialsRef); } return (A) this;
  }
  public boolean hasCredentialsRef() {
    return this.credentialsRef != null;
  }
  public A withNewCredentialsRef(String name) {
    return (A)withCredentialsRef(new LocalObjectReference(name));
  }
  public CredentialsRefNested<A> withNewCredentialsRef() {
    return new CredentialsRefNested(null);
  }
  public CredentialsRefNested<A> withNewCredentialsRefLike(LocalObjectReference item) {
    return new CredentialsRefNested(item);
  }
  public CredentialsRefNested<A> editCredentialsRef() {
    return withNewCredentialsRefLike(java.util.Optional.ofNullable(buildCredentialsRef()).orElse(null));
  }
  public CredentialsRefNested<A> editOrNewCredentialsRef() {
    return withNewCredentialsRefLike(java.util.Optional.ofNullable(buildCredentialsRef()).orElse(new LocalObjectReferenceBuilder().build()));
  }
  public CredentialsRefNested<A> editOrNewCredentialsRefLike(LocalObjectReference item) {
    return withNewCredentialsRefLike(java.util.Optional.ofNullable(buildCredentialsRef()).orElse(item));
  }
  public String getUrl() {
    return this.url;
  }
  public A withUrl(String url) {
    this.url=url; return (A) this;
  }
  public boolean hasUrl() {
    return this.url != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    VenafiTPPFluent that = (VenafiTPPFluent) o;
    if (!java.util.Objects.equals(caBundle, that.caBundle)) return false;

    if (!java.util.Objects.equals(credentialsRef, that.credentialsRef)) return false;

    if (!java.util.Objects.equals(url, that.url)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(caBundle,  credentialsRef,  url,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (caBundle != null) { sb.append("caBundle:"); sb.append(caBundle + ","); }
    if (credentialsRef != null) { sb.append("credentialsRef:"); sb.append(credentialsRef + ","); }
    if (url != null) { sb.append("url:"); sb.append(url); }
    sb.append("}");
    return sb.toString();
  }
  public class CredentialsRefNested<N> extends LocalObjectReferenceFluent<CredentialsRefNested<N>> implements Nested<N>{
    CredentialsRefNested(LocalObjectReference item) {
      this.builder = new LocalObjectReferenceBuilder(this, item);
    }
    LocalObjectReferenceBuilder builder;
    public N and() {
      return (N) VenafiTPPFluent.this.withCredentialsRef(builder.build());
    }
    public N endCredentialsRef() {
      return and();
    }
    
  }
  
}

==> certmanager-model-v1alpha3-6.9.0-sources.jar: io/fabric8/certmanager/api/model/v1alpha3/VenafiTPPFluent.java <==
package io.fabric8.certmanager.api.model.v1alpha3;

import java.lang.SuppressWarnings;
import io.fabric8.certmanager.api.model.meta.v1.LocalObjectReference;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.Object;
import java.lang.String;
import io.fabric8.certmanager.api.model.meta.v1.LocalObjectReferenceBuilder;
import io.fabric8.certmanager.api.model.meta.v1.LocalObjectReferenceFluent;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class VenafiTPPFluent<A extends VenafiTPPFluent<A>> extends BaseFluent<A>{
  public VenafiTPPFluent() {
  }
  
  public VenafiTPPFluent(VenafiTPP instance) {
    this.copyInstance(instance);
  }
  private String caBundle;
  private LocalObjectReferenceBuilder credentialsRef;
  private String url;
  
  protected void copyInstance(VenafiTPP instance) {
    instance = (instance != null ? instance : new VenafiTPP());
  
    if (instance != null) {
        this.withCaBundle(instance.getCaBundle());
        this.withCredentialsRef(instance.getCredentialsRef());
        this.withUrl(instance.getUrl());
        this.withCaBundle(instance.getCaBundle());
        this.withCredentialsRef(instance.getCredentialsRef());
        this.withUrl(instance.getUrl());
      }
  }
  
  public String getCaBundle() {
    return this.caBundle;
  }
  
  public A withCaBundle(String caBundle) {
    this.caBundle=caBundle; return (A) this;
  }
  
  public boolean hasCaBundle() {
    return this.caBundle != null;
  }
  
  public LocalObjectReference buildCredentialsRef() {
    return this.credentialsRef!=null ?this.credentialsRef.build():null;
  }
  
  public A withCredentialsRef(LocalObjectReference credentialsRef) {
    _visitables.get("credentialsRef").remove(this.credentialsRef);
    if (credentialsRef!=null){ this.credentialsRef= new LocalObjectReferenceBuilder(credentialsRef); _visitables.get("credentialsRef").add(this.credentialsRef);} else { this.credentialsRef = null; _visitables.get("credentialsRef").remove(this.credentialsRef); } return (A) this;
  }
  
  public boolean hasCredentialsRef() {
    return this.credentialsRef != null;
  }
  
  public A withNewCredentialsRef(String name) {
    return (A)withCredentialsRef(new LocalObjectReference(name));
  }
  
  public CredentialsRefNested<A> withNewCredentialsRef() {
    return new CredentialsRefNested(null);
  }
  
  public CredentialsRefNested<A> withNewCredentialsRefLike(LocalObjectReference item) {
    return new CredentialsRefNested(item);
  }
  
  public CredentialsRefNested<A> editCredentialsRef() {
    return withNewCredentialsRefLike(java.util.Optional.ofNullable(buildCredentialsRef()).orElse(null));
  }
  
  public CredentialsRefNested<A> editOrNewCredentialsRef() {
    return withNewCredentialsRefLike(java.util.Optional.ofNullable(buildCredentialsRef()).orElse(new LocalObjectReferenceBuilder().build()));
  }
  
  public CredentialsRefNested<A> editOrNewCredentialsRefLike(LocalObjectReference item) {
    return withNewCredentialsRefLike(java.util.Optional.ofNullable(buildCredentialsRef()).orElse(item));
  }
  
  public String getUrl() {
    return this.url;
  }
  
  public A withUrl(String url) {
    this.url=url; return (A) this;
  }
  
  public boolean hasUrl() {
    return this.url != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    VenafiTPPFluent that = (VenafiTPPFluent) o;
    if (!java.util.Objects.equals(caBundle, that.caBundle)) return false;
  
    if (!java.util.Objects.equals(credentialsRef, that.credentialsRef)) return false;
  
    if (!java.util.Objects.equals(url, that.url)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(caBundle,  credentialsRef,  url,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (caBundle != null) { sb.append("caBundle:"); sb.append(caBundle + ","); }
    if (credentialsRef != null) { sb.append("credentialsRef:"); sb.append(credentialsRef + ","); }
    if (url != null) { sb.append("url:"); sb.append(url); }
    sb.append("}");
    return sb.toString();
  }
  public class CredentialsRefNested<N> extends LocalObjectReferenceFluent<CredentialsRefNested<N>> implements Nested<N>{
    CredentialsRefNested(LocalObjectReference item) {
      this.builder = new LocalObjectReferenceBuilder(this, item);
    }
    LocalObjectReferenceBuilder builder;
    
    public N and() {
      return (N) VenafiTPPFluent.this.withCredentialsRef(builder.build());
    }
    
    public N endCredentialsRef() {
      return and();
    }
    
  
  }

}
